@@ -6,7 +6,23 @@
 #' Note that the function will do some basic checks on the \code{request} input
 #' to identify possible problems.
 #'
-#' @param user user (email address) used to sign up for the ECMWF data service,
+#' Two sorts of requests are accepted, a simple data request based upon the
+#' available data in the (raw) CDS repository, and a workflow request which
+#' forwards an anonymous python function to the CDS servers and returns its
+#' results.
+#'
+#' The latter advanced use case is non-trivial, as both python and R code is
+#' required. However, it allows you to offload costly data operations /
+#' aggregation to the ECMWF servers, therefore limiting the amount of data
+#' that needs to be transferred.
+#'
+#' A detailed summary of the use of the python API underpinning the CDS Toolbox
+#' (Editor) these operations is beyond the scope of this package. We refer to
+#' the [CDS Toolbox manual](https://cds.climate.copernicus.eu/toolbox/doc/api.html),
+#' and the small example included in the
+#' [vignettes](https://bluegreen-labs.github.io/ecmwfr/articles/cds_workflow_vignette.html).
+#'
+#' @param user user (email address or ID) provided by the ECMWF data service,
 #' used to retrieve the token set by \code{\link[ecmwfr]{wf_set_key}}
 #' @param path path were to store the downloaded data
 #' @param time_out how long to wait on a download to start (default =
@@ -17,7 +33,8 @@
 #' @param job_name optional name to use as an RStudio job and as output variable
 #'  name. It has to be a syntactically valid name.
 #' @param verbose show feedback on processing
-
+#' @import uuid
+#'
 #' @return the path of the downloaded (requested file) or the an R6 object
 #' with download/transfer information
 #' @seealso \code{\link[ecmwfr]{wf_set_key}}
@@ -88,10 +105,12 @@ wf_request <- function(
       )
     }
 
-    job <-
-      rstudioapi::jobRunScript(path = script,
-                               name = job_name,
-                               exportEnv = "R_GlobalEnv")
+    job <- rstudioapi::jobRunScript(
+      path = script,
+      name = job_name,
+      exportEnv = "R_GlobalEnv"
+      )
+
     return(invisible(job))
   }
 
@@ -108,64 +127,42 @@ wf_request <- function(
     stop("Please provide ECMWF or CDS login credentials and data request!")
   }
 
-  if (missing(user) || is.null(user)) {
-    user <-
-      rbind(
-        keyring::key_list(service = make_key_service(c("webapi"))),
-        keyring::key_list(service = make_key_service(c("cds"))),
-        keyring::key_list(service = make_key_service(c("ads")))
-      )
-    serv <- make_key_service()
-    user <-
-      user[substr(user$service, 1,  nchar(serv)) == serv, ][["username"]]
+  # check for user
+  if (missing(user)){
+    stop("Missing user credentials, please provide a valid user/ID!")
   }
 
-  # checks user login, the request layout and
-  # returns the service to use if successful
-  wf_check <-
-    lapply(user, function(u)
-      try(wf_check_request(u, request), silent = TRUE))
-  correct <- which(!vapply(wf_check, inherits, TRUE, "try-error"))
-
-  if (length(correct) == 0) {
-    stop(
-      sprintf(
-        "Data identifier %s is not found in Web API, CDS or ADS datasets.
-                 Or your login credentials do not match your request.",
-        request$dataset_short_name
-      ),
-      call. = FALSE
-    )
-  }
-
-  wf_check <- wf_check[[correct]]
-  user <- user[correct]
+  # Guessing credentials/service
+  service_info <- guess_service(request, user)
 
   if (verbose)
   {
     message("Requesting data to the ",
-            wf_check$service,
+            service_info$service,
             " service with username ",
-            user)
+            service_info$user)
   }
 
   # split out data
-  service <- wf_check$service
-  url <- wf_check$url
+  service <- service_info$service
+  url <- service_info$url
 
   # Select the appropriate service
   service <- switch(
     service,
     webapi = webapi_service,
     cds = cds_service,
+    cds_workflow = cds_workflow,
     ads = ads_service
     )
 
   # Create request and submit to service
-  request <- service$new(request = request,
-                     user = user,
-                     url = url,
-                     path = path)
+  request <- service$new(
+    request = request,
+    user = service_info$user,
+    url = service_info$url,
+    path = path
+    )
 
   # Submit the request
   request$submit()
@@ -174,7 +171,15 @@ wf_request <- function(
   if (transfer) {
     request$transfer(time_out = time_out)
     if (request$is_success()) {
-      return(request$get_file())
+
+      # download the data to a set file location
+      file_location <- request$get_file()
+
+      # delete from queue
+      request$delete()
+
+      # return file location
+      return(file_location)
     }
     message("Transfer was not successfull - please check your request later at:")
     message(request$get_url())
